#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # First steps with pandas_streaming
# 
# A few difference between [pandas](http://pandas.pydata.org/) and *pandas_streaming*.

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# ## pandas to pandas_streaming

# In[2]:


from pandas import DataFrame
df = DataFrame(data=dict(X=[4.5, 6, 7], Y=["a", "b", "c"]))
df


# We create a streaming dataframe:

# In[3]:


from pandas_streaming.df import StreamingDataFrame
sdf = StreamingDataFrame.read_df(df)
sdf


# In[4]:


sdf.to_dataframe()


# Internally, StreamingDataFrame implements an iterator on dataframes and then tries to replicate the same interface as [pandas.DataFrame](https://pandas.pydata.org/pandas-docs/stable/generated/pandas.DataFrame.html) possibly wherever it is possible to manipulate data without loading everything into memory.

# In[5]:


sdf2 = sdf.concat(sdf)
sdf2.to_dataframe()


# In[6]:


m = DataFrame(dict(Y=["a", "b"], Z=[10, 20]))
m


# In[7]:


sdf3 = sdf2.merge(m, left_on="Y", right_on="Y", how="outer")
sdf3.to_dataframe()


# In[8]:


sdf2.to_dataframe().merge(m, left_on="Y", right_on="Y", how="outer")


# The order might be different.

# In[9]:


sdftr, sdfte = sdf2.train_test_split(test_size=0.5)
sdfte.head()


# In[10]:


sdftr.head()


# ## split a big file

# In[11]:


sdf2.to_csv("example.txt")


# In[12]:


new_sdf = StreamingDataFrame.read_csv("example.txt")
new_sdf.train_test_split("example.{}.txt", streaming=False)


# In[13]:


import glob
glob.glob("ex*.txt")


# In[14]: